Package: RCytoGPS
Version: 1.2.13
Date: 2026-07-06
Title: Using Cytogenetics Data in R
Authors@R: c(person(given = c("Kevin", "R."),
                      family = "Coombes",
                      role = c("aut", "cre"),
                      email = "krc@silicovore.com"),
               person(given = "Dwayne",
                      family = "Tally",
                      role = "aut"))
Description: Defines classes and methods to process text-based
  cytogenetics using the CytoGPS web site, then import the results
  into R for further analysis and graphing.
Depends: R (>= 4.4)
Suggests: knitr, rmarkdown, Mercator
Imports: methods, graphics, grDevices, rjson
VignetteBuilder: knitr
License: Apache License (== 2.0)
URL: http://oompa.r-forge.r-project.org/
Author: Kevin R. Coombes [aut, cre],
  Dwayne Tally [aut]
Maintainer: Kevin R. Coombes <krc@silicovore.com>
Repository: R-Forge
Repository/R-Forge/Project: thresher
Repository/R-Forge/Revision: 299
Repository/R-Forge/DateTimeStamp: 2026-07-06 17:43:31
Date/Publication: 2026-07-06 17:43:31
NeedsCompilation: no
Packaged: 2026-07-06 18:04:10 UTC; rforge
