###
### NAMESPACE
###
import(methods)
importFrom("graphics", "image", "barplot", "abline", "layout",
           "legend", "lines", "mtext", "par", "title",
           "axis", "plot", "rect", "text", "box")
importFrom("grDevices", "palette", "col2rgb", "rgb")
importFrom("rjson", "fromJSON")

exportClasses("Chromosome", "CytobandData")
export("Chromosome", "CytobandData")
exportMethods("image", "barplot", "summary")

export("readLGF", "preclean")
